Struct Istr
#[repr(transparent)]pub struct Istr(pub u32);Expand description
interrupt status register
Tuple Fields
0: u32Implementations
impl Istr
impl Istr
pub const fn sof(&self) -> bool
pub const fn sof(&self) -> bool
beginning of a new USB frame and it is set when a SOF packet arrives through the USB bus
pub const fn set_sof(&mut self, val: bool)
pub const fn set_sof(&mut self, val: bool)
beginning of a new USB frame and it is set when a SOF packet arrives through the USB bus
pub const fn set_reset(&mut self, val: bool)
pub const fn set_reset(&mut self, val: bool)
peripheral detects an active USB RESET signal at its inputs
pub const fn susp(&self) -> bool
pub const fn susp(&self) -> bool
no traffic has been received for 3 ms, indicating a suspend mode request from the USB bus
pub const fn set_susp(&mut self, val: bool)
pub const fn set_susp(&mut self, val: bool)
no traffic has been received for 3 ms, indicating a suspend mode request from the USB bus
pub const fn err(&self) -> bool
pub const fn err(&self) -> bool
One of No ANSwer, Cyclic Redundancy Check, Bit Stuffing or Framing format Violation error occurred
pub const fn set_err(&mut self, val: bool)
pub const fn set_err(&mut self, val: bool)
One of No ANSwer, Cyclic Redundancy Check, Bit Stuffing or Framing format Violation error occurred
pub const fn pmaovr(&self) -> bool
pub const fn pmaovr(&self) -> bool
microcontroller has not been able to respond in time to an USB memory request
pub const fn set_pmaovr(&mut self, val: bool)
pub const fn set_pmaovr(&mut self, val: bool)
microcontroller has not been able to respond in time to an USB memory request